@@ -1,7 +1,7 @@
 /*
  * ct_actions_file.cc
  *
- * Copyright 2009-2023
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -183,9 +183,12 @@ void CtActions::preferences_import()
     _pCtConfig->nodesOnNodeNameHeader = ctConfigImported.nodesOnNodeNameHeader;
     _pCtConfig->maxMatchesInPage = ctConfigImported.maxMatchesInPage;
     _pCtConfig->toolbarIconSize = ctConfigImported.toolbarIconSize;
-    _pCtConfig->currColors['f'] = ctConfigImported.currColors['f'];
-    _pCtConfig->currColors['b'] = ctConfigImported.currColors['b'];
-    _pCtConfig->currColors['n'] = ctConfigImported.currColors['n'];
+    _pCtConfig->currColour_fg = ctConfigImported.currColour_fg;
+    _pCtConfig->currColour_bg = ctConfigImported.currColour_bg;
+    _pCtConfig->currColour_nn = ctConfigImported.currColour_nn;
+    for (const Gdk::RGBA& colour : ctConfigImported.coloursUserPalette) {
+        _pCtConfig->coloursUserPalette.move_or_push_front(colour);
+    }
     _pCtConfig->restoreExpColl = ctConfigImported.restoreExpColl;
     _pCtConfig->nodesBookmExp = ctConfigImported.nodesBookmExp;
     _pCtConfig->nodesIcons = ctConfigImported.nodesIcons;
@@ -210,6 +213,10 @@ void CtActions::preferences_import()
     _pCtConfig->scrollBeyondLastLine = ctConfigImported.scrollBeyondLastLine;
     _pCtConfig->spacesInsteadTabs = ctConfigImported.spacesInsteadTabs;
     _pCtConfig->cursorBlink = ctConfigImported.cursorBlink;
+    _pCtConfig->overlayScroll = ctConfigImported.overlayScroll;
+    _pCtConfig->scrollSliderMin = ctConfigImported.scrollSliderMin;
+    _pCtConfig->textMarginLeft = ctConfigImported.textMarginLeft;
+    _pCtConfig->textMarginRight = ctConfigImported.textMarginRight;
     _pCtConfig->tabsWidth = ctConfigImported.tabsWidth;
     _pCtConfig->anchorSize = ctConfigImported.anchorSize;
     _pCtConfig->latexSizeDpi = ctConfigImported.latexSizeDpi;
@@ -262,6 +269,7 @@ void CtActions::preferences_import()
     _pCtConfig->codeboxMatchBra = ctConfigImported.codeboxMatchBra;
     _pCtConfig->codeboxSynHighl = ctConfigImported.codeboxSynHighl;
     _pCtConfig->codeboxAutoResize = ctConfigImported.codeboxAutoResize;
+    _pCtConfig->codeboxWithToolbar = ctConfigImported.codeboxWithToolbar;
     _pCtConfig->tableRows = ctConfigImported.tableRows;
     _pCtConfig->tableColumns = ctConfigImported.tableColumns;
     _pCtConfig->tableColWidthDefault = ctConfigImported.tableColWidthDefault;
@@ -327,7 +335,7 @@ void CtActions::preferences_import()
     }
     _pCtConfig->startOnSystray = ctConfigImported.startOnSystray;
     _pCtConfig->autosaveOn = ctConfigImported.autosaveOn;
-    _pCtConfig->autosaveVal = ctConfigImported.autosaveVal;
+    _pCtConfig->autosaveMinutes = ctConfigImported.autosaveMinutes;
     _pCtConfig->bookmarksInTopMenu = ctConfigImported.bookmarksInTopMenu;
     _pCtConfig->menusTooltips = ctConfigImported.menusTooltips;
     _pCtConfig->toolbarTooltips = ctConfigImported.toolbarTooltips;
