@@ -40,7 +40,7 @@ protected:
 
 public:
     static Glib::RefPtr<CtApp> create(const Glib::ustring application_id_postfix = Glib::ustring{});
-    void                       close_all_windows(const bool userCanInteract = true);
+    void                       close_all_windows(const bool fromKillCallback);
     void                       systray_show_hide_windows();
 
 protected:
