@@ -1,7 +1,7 @@
 /*
  * ct_dialogs.cc
  *
- * Copyright 2009-2023
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -163,8 +163,7 @@ void CtDialogs::bookmarks_handle_dialog(CtMainWin* pCtMainWin)
         CtMiscUtil::node_siblings_sort(rModel, rModel->children(), need_swap);
     });
 
-    if (dialog.run() != Gtk::RESPONSE_ACCEPT)
-    {
+    if (dialog.run() != Gtk::RESPONSE_ACCEPT) {
         return;
     }
 
@@ -179,24 +178,19 @@ void CtDialogs::bookmarks_handle_dialog(CtMainWin* pCtMainWin)
     });
 
     std::list<gint64> removed_bookmarks;
-    for (const gint64& node_id : bookmarks)
-    {
-        if (0 == temp_bookmarks.count(node_id))
-        {
+    for (const gint64& node_id : bookmarks) {
+        if (0 == temp_bookmarks.count(node_id)) {
             removed_bookmarks.push_back(node_id);
         }
     }
 
     ctTreestore.bookmarks_set(temp_bookmarks_order);
     gint64 curr_node_id = pCtMainWin->curr_tree_iter().get_node_id();
-    for (gint64& node_id: removed_bookmarks)
-    {
-        Gtk::TreeIter tree_iter = ctTreestore.get_node_from_node_id(node_id);
-        if (tree_iter)
-        {
-            ctTreestore.update_node_aux_icon(tree_iter);
-            if (curr_node_id == node_id)
-            {
+    for (gint64& node_id: removed_bookmarks) {
+        CtTreeIter ct_tree_iter = ctTreestore.get_node_from_node_id(node_id);
+        if (ct_tree_iter) {
+            ctTreestore.update_node_aux_icon(ct_tree_iter);
+            if (curr_node_id == node_id) {
                 pCtMainWin->menu_update_bookmark_menu_item(false);
             }
         }
@@ -299,11 +293,11 @@ bool CtDialogs::choose_data_storage_dialog(CtMainWin* pCtMainWin, CtStorageSelec
     auto pCtConfig = pCtMainWin->get_ct_config();
     auto hbox_autosave = Gtk::manage(new Gtk::Box{Gtk::ORIENTATION_HORIZONTAL, 4/*spacing*/});
     auto checkbutton_autosave = Gtk::manage(new Gtk::CheckButton{_("Autosave Every")});
-    Glib::RefPtr<Gtk::Adjustment> adjustment_autosave = Gtk::Adjustment::create(pCtConfig->autosaveVal, 1, 1000, 1);
+    Glib::RefPtr<Gtk::Adjustment> adjustment_autosave = Gtk::Adjustment::create(pCtConfig->autosaveMinutes, 1, 1000, 1);
     auto spinbutton_autosave = Gtk::manage(new Gtk::SpinButton(adjustment_autosave));
     auto label_autosave = Gtk::manage(new Gtk::Label{_("Minutes")});
     checkbutton_autosave->set_active(pCtConfig->autosaveOn);
-    spinbutton_autosave->set_value(pCtConfig->autosaveVal);
+    spinbutton_autosave->set_value(pCtConfig->autosaveMinutes);
     spinbutton_autosave->set_sensitive(pCtConfig->autosaveOn);
     hbox_autosave->pack_start(*checkbutton_autosave, false, false);
     hbox_autosave->pack_start(*spinbutton_autosave, false, false);
@@ -315,7 +309,7 @@ bool CtDialogs::choose_data_storage_dialog(CtMainWin* pCtMainWin, CtStorageSelec
         spinbutton_autosave->set_sensitive(pCtConfig->autosaveOn);
     });
     spinbutton_autosave->signal_value_changed().connect([pCtConfig, pCtMainWin, spinbutton_autosave](){
-        pCtConfig->autosaveVal = spinbutton_autosave->get_value_as_int();
+        pCtConfig->autosaveMinutes = spinbutton_autosave->get_value_as_int();
         pCtMainWin->file_autosave_restart();
     });
 
@@ -522,7 +516,7 @@ void CtDialogs::dialog_about(Gtk::Window& parent, Glib::RefPtr<Gdk::Pixbuf> icon
     auto dialog = Gtk::AboutDialog();
     dialog.set_program_name("CherryTree");
     dialog.set_version(CtConst::CT_VERSION);
-    dialog.set_copyright("Copyright © 2009-2023\n"
+    dialog.set_copyright("Copyright © 2009-2024\n"
                          "Giuseppe Penone <giuspen@gmail.com>\n"
                          "Evgenii Gurianov <https://github.com/txe>");
     dialog.set_comments(_("A Hierarchical Note Taking Application, featuring Rich Text and Syntax Highlighting"));
@@ -546,7 +540,7 @@ MA 02110-1301, USA.
     dialog.set_authors({"Giuseppe Penone <giuspen@gmail.com>", "Evgenii Gurianov <https://github.com/txe>"});
     dialog.set_artists({"Ugo Yak <https://www.instagram.com/ugoyak.art/>", "SVG Repo <https://www.svgrepo.com/>", "OCAL <http://www.openclipart.org/>", "Zeltak <zeltak@gmail.com>", "Angelo Penone <angelo.penone@gmail.com>"});
     dialog.set_translator_credits(Glib::ustring{} +
- _("Arabic")+" (ar) Mohamed Milodi <milodi500@gmail.com>"+CtConst::CHAR_NEWLINE+
+ _("Arabic")+" (ar) Abdulrahman Karajeh <abdulrahmankarajeh08@gmail.com>"+CtConst::CHAR_NEWLINE+
  _("Armenian")+" (hy) Seda Stamboltsyan <sedastam@yandex.com>"+CtConst::CHAR_NEWLINE+
  _("Bulgarian")+" (bg) Iliya Nikolaev <iliya.nikolaev@gmail.com>"+CtConst::CHAR_NEWLINE+
  _("Chinese Simplified")+" (zh_CN) Wang Yu <krwy0330@gmail.com>"+CtConst::CHAR_NEWLINE+
@@ -638,7 +632,7 @@ void CtDialogs::summary_info_dialog(CtMainWin* pCtMainWin, const CtSummaryInfo&
     Gtk::Label label_ta_key;
     label_ta_key.set_markup(Glib::ustring{"<b>"} + _("Number of Tables") + "</b>");
     grid.attach(label_ta_key, 0, 6, 1, 1);
-    Gtk::Label label_ta_val{str::format("{} + {}", summaryInfo.heavytables_num, summaryInfo.lighttables_num)};
+    Gtk::Label label_ta_val{fmt::format("{} + {}", summaryInfo.heavytables_num, summaryInfo.lighttables_num)};
     grid.attach(label_ta_val, 1, 6, 1, 1);
     Gtk::Label label_cb_key;
     label_cb_key.set_markup(Glib::ustring{"<b>"} + _("Number of CodeBoxes") + "</b>");
@@ -650,6 +644,11 @@ void CtDialogs::summary_info_dialog(CtMainWin* pCtMainWin, const CtSummaryInfo&
     grid.attach(label_an_key, 0, 8, 1, 1);
     Gtk::Label label_an_val{std::to_string(summaryInfo.anchors_num)};
     grid.attach(label_an_val, 1, 8, 1, 1);
+    Gtk::Label label_shared_key;
+    label_shared_key.set_markup(Glib::ustring{"<b>"} + _("Number of Shared Nodes / Groups") + "</b>");
+    grid.attach(label_shared_key, 0, 9, 1, 1);
+    Gtk::Label label_shared_val{fmt::format("{} / {}", summaryInfo.nodes_shared_tot, summaryInfo.nodes_shared_groups)};
+    grid.attach(label_shared_val, 1, 9, 1, 1);
     Gtk::Box* pContentArea = dialog.get_content_area();
     pContentArea->pack_start(grid);
     pContentArea->show_all();
