@@ -67,7 +67,7 @@ void CtExport2Pango::pango_get_from_treestore_node(CtTreeIter node_iter, int sel
 
         if (auto anchor = dynamic_cast<CtImageAnchor*>(widget)) {
             out_slots.emplace_back(std::make_shared<CtPangoDest>(
-                "<sup>⚓</sup>",
+                "<sup> </sup>", // ⚓
                 CtConst::RICH_TEXT_ID,
                 widget_indent,
                 "name='" + generate_tag(node_iter.get_node_id(), anchor->get_anchor_name()) + "'",
@@ -342,7 +342,7 @@ std::shared_ptr<CtPangoText> CtExport2Pango::_pango_link_url(const Glib::ustring
              link_entry.type == CtConst::LINK_TYPE_FOLD)
     {
         std::string fileOrFold = link_entry.type == CtConst::LINK_TYPE_FILE ? link_entry.file.raw() : link_entry.fold.raw();
-#ifdef _WIN32
+#if defined(_WIN32) || defined(__APPLE__)
         const std::string encoding = CtStrUtil::get_encoding(fileOrFold.c_str(), fileOrFold.size());
         if (encoding == "ASCII") {
             uri = (Glib::path_is_absolute(fileOrFold) ? "uri='file://":"uri='") + str::xml_escape(fs::path{fileOrFold}.string_unix()) + "'";
@@ -350,9 +350,9 @@ std::shared_ptr<CtPangoText> CtExport2Pango::_pango_link_url(const Glib::ustring
         else {
             uri = "uri='file://non_supported_encoding_" + encoding + "'";
         }
-#else // !_WIN32
+#else /* !_WIN32 && !__APPLE__ */
         uri = (Glib::path_is_absolute(fileOrFold) ? "uri='file://":"uri='") + str::xml_escape(fileOrFold) + "'";
-#endif // !_WIN32
+#endif /* !_WIN32 && !__APPLE__ */
     }
     else {
         spdlog::debug("invalid link entry {}, text {}", link, tagged_text);
@@ -365,13 +365,17 @@ std::shared_ptr<CtPangoText> CtExport2Pango::_pango_link_url(const Glib::ustring
 
 void CtExport2Pdf::node_export_print(const fs::path& pdf_filepath, CtTreeIter tree_iter, const CtExportOptions& options, int sel_start, int sel_end)
 {
+    Glib::RefPtr<Gsv::Buffer> rTextBuffer = tree_iter.get_node_text_buffer();
+    if (not rTextBuffer) {
+        throw std::runtime_error(str::format(_("Failed to retrieve the content of the node '%s'"), tree_iter.get_node_name()));
+    }
     std::vector<CtPangoObjectPtr> pango_slots;
     if (tree_iter.get_node_is_text()) {
         CtExport2Pango{_pCtMainWin}.pango_get_from_treestore_node(tree_iter, sel_start, sel_end, pango_slots);
     }
     else {
         Glib::ustring text = CtExport2Pango{_pCtMainWin}.pango_get_from_code_buffer(
-            tree_iter.get_node_text_buffer(), sel_start, sel_end, tree_iter.get_node_syntax_highlighting());
+            rTextBuffer, sel_start, sel_end, tree_iter.get_node_syntax_highlighting());
         pango_slots.push_back(std::make_shared<CtPangoText>(text, tree_iter.get_node_syntax_highlighting(), 0/*indent*/, PANGO_DIRECTION_LTR));
     }
 
@@ -399,15 +403,21 @@ void CtExport2Pdf::tree_export_print(const fs::path& pdf_filepath, CtTreeIter tr
     _pCtMainWin->get_ct_print().print_text(pdf_filepath, tree_pango_slots);
 }
 
-void CtExport2Pdf::_nodes_all_export_print_iter(CtTreeIter tree_iter, const CtExportOptions& options, std::vector<CtPangoObjectPtr>& tree_pango_slots)
+void CtExport2Pdf::_nodes_all_export_print_iter(CtTreeIter tree_iter,
+                                                const CtExportOptions& options,
+                                                std::vector<CtPangoObjectPtr>& tree_pango_slots)
 {
+    Glib::RefPtr<Gsv::Buffer> rTextBuffer = tree_iter.get_node_text_buffer();
+    if (not rTextBuffer) {
+        throw std::runtime_error(str::format(_("Failed to retrieve the content of the node '%s'"), tree_iter.get_node_name()));
+    }
     std::vector<CtPangoObjectPtr> node_pango_slots;
     if (tree_iter.get_node_is_text()) {
         CtExport2Pango{_pCtMainWin}.pango_get_from_treestore_node(tree_iter, -1, -1, node_pango_slots);
     }
     else {
         Glib::ustring text = CtExport2Pango{_pCtMainWin}.pango_get_from_code_buffer(
-            tree_iter.get_node_text_buffer(), -1, -1, tree_iter.get_node_syntax_highlighting());
+            rTextBuffer, -1, -1, tree_iter.get_node_syntax_highlighting());
         node_pango_slots.push_back(std::make_shared<CtPangoText>(text, tree_iter.get_node_syntax_highlighting(), 0/*indent*/, PANGO_DIRECTION_LTR));
     }
 
