@@ -194,15 +194,23 @@ bool copy_file(const path& from, const path& to)
 
 bool move_file(const path& from, const path& to)
 {
-    try {
-        Glib::RefPtr<Gio::File> rFileFrom = Gio::File::create_for_path(from.string());
-        Glib::RefPtr<Gio::File> rFileTo = Gio::File::create_for_path(to.string());
-        return rFileFrom->move(rFileTo, Gio::FILE_COPY_OVERWRITE);
-    }
-    catch (Gio::Error& error) {
-        spdlog::debug("fs::move_file, error: {}, from: {}, to: {}", error.what(), from.string(), to.string());
-        return false;
+    GFile* pGFile_from = g_file_new_for_path(from.c_str());
+    GFile* pGFile_to = g_file_new_for_path(to.c_str());
+    GError* pError = NULL;
+    bool retSuccess = g_file_move(pGFile_from,
+                                  pGFile_to,
+                                  G_FILE_COPY_OVERWRITE,
+                                  NULL,
+                                  NULL,  // GFileProgressCallback
+                                  NULL,  // data
+                                  &pError);
+    if (pError) {
+        spdlog::warn("{}, error: {}, from: {}, to: {}", __FUNCTION__, pError->message, from.string(), to.string());
+        g_error_free(pError);
     }
+    g_object_unref(pGFile_from);
+    g_object_unref(pGFile_to);
+    return retSuccess;
 }
 
 path absolute(const path& p)
@@ -347,9 +355,9 @@ path prepare_export_folder(const path& dir_place, path new_folder, bool overwrit
         }
         else {
             int n = 2;
-            while (fs::is_directory(dir_place / (new_folder.string() + str::format("{:03d}", n))))
+            while (fs::is_directory(dir_place / (new_folder.string() + fmt::format("{:03d}", n))))
                 n += 1;
-            new_folder += str::format("{:03d}", n);
+            new_folder += fmt::format("{:03d}", n);
         }
     }
     return new_folder;
@@ -357,18 +365,22 @@ path prepare_export_folder(const path& dir_place, path new_folder, bool overwrit
 
 std::uintmax_t remove_all(const path& dir)
 {
-    std::uintmax_t count = 0;
-    for (const auto& file : get_dir_entries(dir)) {
-        if (is_directory(file)) {
-            count += remove_all(file);
-        }
-        else {
-            ++count;
-            remove(file);
+    std::uintmax_t count{0u};
+    if (fs::is_directory(dir)) {
+        for (const auto& file : get_dir_entries(dir)) {
+            if (is_directory(file)) {
+                count += remove_all(file);
+            }
+            else {
+                ++count;
+                remove(file);
+            }
         }
     }
-    remove(dir);
-    ++count;
+    if (fs::exists(dir)) {
+        remove(dir);
+        ++count;
+    }
     return count;
 }
 
