@@ -33,7 +33,6 @@ public:
     {
         _no_gui = true;
         _on_startup(); // so that _uCtTmp is ready straight away
-        _uCtCfg->usePandoc = false; // ensure html from gtksourceview syntax highlighting
     }
     CtTmp* getCtTmp() { return _uCtTmp.get(); }
     void register_args(const std::vector<std::string>* pVecArgs) { _pVecArgs = pVecArgs; }
@@ -132,10 +131,11 @@ TEST_P(ExportsMultipleParametersTests, ChecksExports)
 INSTANTIATE_TEST_CASE_P(
         ExportsTests,
         ExportsMultipleParametersTests,
-        ::testing::Values(std::make_tuple(UT::testCtbDocPath, "--export_to_txt_dir"),
-                          std::make_tuple(UT::testCtdDocPath, "--export_to_txt_dir"),
-                          std::make_tuple(UT::testCtbDocPath, "--export_to_pdf_dir"),
-                          std::make_tuple(UT::testCtdDocPath, "--export_to_pdf_dir"),
-                          std::make_tuple(UT::testCtbDocPath, "--export_to_html_dir"),
-                          std::make_tuple(UT::testCtdDocPath, "--export_to_html_dir"))
+        ::testing::Values(
+            std::make_tuple(UT::testCtbDocPath, "--export_to_txt_dir"),
+            std::make_tuple(UT::testCtdDocPath, "--export_to_txt_dir"),
+            std::make_tuple(UT::testCtbDocPath, "--export_to_pdf_dir"),
+            std::make_tuple(UT::testCtdDocPath, "--export_to_pdf_dir"),
+            std::make_tuple(UT::testCtbDocPath, "--export_to_html_dir"),
+            std::make_tuple(UT::testCtdDocPath, "--export_to_html_dir"))
 );
