@@ -1,7 +1,7 @@
 /*
  * tests_misc_utils.cpp
  *
- * Copyright 2009-2023
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -175,6 +175,12 @@ TEST(MiscUtilsGroup, getFontMisc)
     ASSERT_STREQ("Noto Sans 9", CtFontUtil::get_font_str("Noto Sans", 9).c_str());
 }
 
+TEST(MiscUtilsGroup, rgb_to_string_24)
+{
+    ASSERT_STREQ("#452acb", CtRgbUtil::rgb_to_string_24(Gdk::RGBA{"rgb(69,42,203)"}).c_str());
+    ASSERT_STREQ("#452acb", CtRgbUtil::rgb_to_string_24(Gdk::RGBA{"#452acb"}).c_str());
+}
+
 TEST(MiscUtilsGroup, set_rgb24str_from_rgb24int)
 {
     guint32 int24 = (0xf1 << 16) | (0xab << 8) | 0x57;
